# -*- coding: utf-8 -*-
"""
    __init__.py

    :copyright: (c) 2017 by Joe Paul.
    :license: see LICENSE for details.
"""
from kiteconnect import KiteConnect


__all__ = ('FlaskKiteConnect', )
__version__ = '0.1.0'


class FlaskKiteConnect(object):
    """
        Flask extension for kiteconnect api

        app = Flask(__name__)
        kiteconnect = FlaskKiteConnect(app)

    """

    def __init__(self, app=None):
        self._client = None

        if app is not None:
            self.init_app(app)

    def init_app(self, app):
        """Initialize the kiteconnect client

        :param app: Flask app instance
        """
        self._client = KiteConnect(
            app.config.get('KITECONNECT_API_KEY')
        )
        access_token = app.config.get('KITECONNECT_ACCESS_TOKEN')
        if access_token:
            self._client.set_access_token(access_token)

    def __getattr__(self, name):
        """Proxy methods to the private held object
        """
        return getattr(self._client, name)



#!/usr/bin/env python

from setuptools import setup

setup(
    name="flask-kiteconnect",
    version="0.1.0",
    description="Easy flask extension for kiteconnect",
    author="Joe Paul",
    author_email="joeirimpan@gmail.com",
    packages=["flask_kiteconnect"],
    download_url="https://github.com/joeirimpan/flask-kiteconnect",
    license="MIT",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Intended Audience :: Financial and Insurance Industry",
        "Programming Language :: Python",
        "Natural Language :: English",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Topic :: Office/Business :: Financial :: Investment",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Software Development :: Libraries"
    ],
    install_requires=['kiteconnect>=3.7.0.b5'],
    test_suite='tests',
    tests_require=['Flask', 'pytest', 'pytest-mock']
)
